(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 13.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     87497,       1924]
NotebookOptionsPosition[     84559,       1868]
NotebookOutlinePosition[     84974,       1884]
CellTagsIndexPosition[     84931,       1881]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Vector Decomposition and Vector Products", "Title",
 CellChangeTimes->{{3.88513645371734*^9, 3.8851364784149723`*^9}, {
  3.8851436072293286`*^9, 
  3.885143609841386*^9}},ExpressionUUID->"fdd7ef63-d95a-4c69-ae57-\
0419edbe79a0"],

Cell[CellGroupData[{

Cell["Background and Simulation Information", "Chapter",
 CellChangeTimes->{{3.8851364912565355`*^9, 3.8851364946546755`*^9}, {
  3.885137039826197*^9, 
  3.8851370547774315`*^9}},ExpressionUUID->"d334e38b-2210-4f02-b519-\
3c1c5cb73a9d"],

Cell[TextData[{
 "This simulation creates vector decompositions and helps you visualize the \
dot and cross products of two vectors that lie in the same plane. ",
 Cell[BoxData[
  FormBox[
   TemplateBox[<|"boxes" -> FormBox[
       OverscriptBox[
        StyleBox["A", "TI"], "\[RightVector]"], TraditionalForm], 
     "errors" -> {}, "input" -> "\\vec{A}", "state" -> "Boxes"|>,
    "TeXAssistantTemplate"], TraditionalForm]],
  FontSize->16,ExpressionUUID->"61568f23-b622-4788-9931-773a6335c88a"],
 StyleBox[" ",
  FontSize->16],
 "and its components will be shown in red, while ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    StyleBox[
     TemplateBox[<|"boxes" -> FormBox[
         OverscriptBox[
          StyleBox["B", "TI"], "\[RightVector]"], TraditionalForm], 
       "errors" -> {}, "input" -> "\\vec{B}", "state" -> "Boxes"|>,
      "TeXAssistantTemplate"],
     FontSize->16], " ", "and", " ", "its", " ", "components", " ", "will", 
    " ", "be", " ", "shown", " ", "in", " ", "blue"}], TraditionalForm]],
  ExpressionUUID->"a99acbc7-d095-41a6-b915-024dc198f1fa"],
 "\nRecall (e.g. from class), that the dot product multiplies parallel \
components of vectors together and ignores components that are perpendicular \
entirely. The cross product does the opposite, it multiplies perpendicular \
components together while ignoring parallel ones. The usage of these two \
objects might not be obvious yet, so consider an example. If a box is sliding \
across a table, pushing directly up on the box won\[CloseCurlyQuote]t make it \
speed up or slow down, but applying a force against its motion will make a \
difference in the objects speed. Thus the closer a force is to being parallel \
to the velocity of the box, the larger the contribution. The cross product is \
a little tougher. Go find a cylindrical object like a water bottle. Now put \
the cylinder on a flat surface so that it is free to roll. Put your finger on \
the top and push straight down..The cylinder won\[CloseCurlyQuote]t rotate. \
If you keep your finger in the same place and apply a force that isn\
\[CloseCurlyQuote]t straight down, the cylinder will begin to roll. In this \
case, the closer the force is to being perpendicular to the radius of the \
cylinder, the larger the spin will be.\n"
}], "Text",
 CellChangeTimes->{{3.885136505686141*^9, 3.8851365276275687`*^9}, {
   3.885136678618148*^9, 3.8851367152789054`*^9}, {3.8851367970522566`*^9, 
   3.8851368612997727`*^9}, 3.8851368953665333`*^9, 3.885137008471366*^9, {
   3.885137059311641*^9, 3.885137156072686*^9}, {3.885137237772416*^9, 
   3.885137788837031*^9}},ExpressionUUID->"3bd37227-8a2c-4316-85c3-\
4a71fbb857ff"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Instructions", "Chapter",
 CellChangeTimes->{{3.8851378096606035`*^9, 
  3.8851378214575863`*^9}},ExpressionUUID->"ab9037fe-bc49-4696-817a-\
afc31aca4477"],

Cell["\<\
Think about a vector in the x-y plane. The vector can be thought of as a sum \
of a vector that points only in the x direction, and one that points only in \
the y direction. We call these component vectors. We want to make sure that \
we understand the lengths of those components. Go ahead and play with the \
simulation for a minute and watch what happens to the A vector decomposition \
when you change the angle and length of vector A. Pay particular attention to \
what happens if A is purely along the x or y axis.\
\>", "ItemNumbered",
 CellChangeTimes->{{3.8851378267339425`*^9, 3.885137977797906*^9}, {
  3.8851380690484805`*^9, 3.8851381448683357`*^9}, {3.885138214643474*^9, 
  3.8851382321600437`*^9}, {3.88513826758963*^9, 
  3.885138272856701*^9}},ExpressionUUID->"f853a84d-fb04-4e6a-b3ce-\
236bfbdc98c5"],

Cell[TextData[{
 "If it isn\[CloseCurlyQuote]t obvious yet where the values for the component \
vectors come from, look at the second panel on the left. In this panel, we \
are using that the starting point of a vector doesn\[CloseCurlyQuote]t \
matter. We can translate the vector\[CloseCurlyQuote]s start anywhere we want \
to; as long as we don\[CloseCurlyQuote]t change the magnitude or the \
direction that it points, it is the same vector. The dashed version of ",
 Cell[BoxData[
  FormBox[
   TemplateBox[<|"boxes" -> FormBox[
       SubscriptBox[
        StyleBox["B", "TI"], 
        StyleBox["y", "TI"]], TraditionalForm], "errors" -> {}, "input" -> 
     "B_y", "state" -> "Boxes"|>,
    "TeXAssistantTemplate"], TraditionalForm]],ExpressionUUID->
  "2c3ebb30-c374-47a4-a10d-a12c9f3c24bb"],
 " , ",
 Cell[BoxData[
  FormBox[
   TemplateBox[<|"boxes" -> FormBox[
       SubscriptBox[
        StyleBox["B", "TI"], 
        StyleBox["x", "TI"]], TraditionalForm], "errors" -> {}, "input" -> 
     "B_x", "state" -> "Boxes"|>,
    "TeXAssistantTemplate"], TraditionalForm]],ExpressionUUID->
  "2b0e0ebe-9c17-498c-a685-75a4600db2df"],
 " and ",
 Cell[BoxData[
  FormBox[
   TemplateBox[<|"boxes" -> FormBox[
       StyleBox["B", "TI"], TraditionalForm], "errors" -> {}, "input" -> "B", 
     "state" -> "Boxes"|>,
    "TeXAssistantTemplate"], TraditionalForm]],ExpressionUUID->
  "65c145e0-8729-46a5-92d3-966869d5a9e1"],
 " form a right triangle. Recall from your previous trig knowledge the \
definitions of sine and cosine. Now we can see that the x component is given \
by ",
 Cell[BoxData[
  FormBox[
   TemplateBox[<|"boxes" -> FormBox[
       RowBox[{
         SubscriptBox[
          StyleBox["B", "TI"], 
          StyleBox["x", "TI"]], "\[LongEqual]", 
         StyleBox["B", "TI"], "cos", "\[Theta]"}], TraditionalForm], 
     "errors" -> {}, "input" -> "B_x=B\\cos\\theta", "state" -> "Boxes"|>,
    "TeXAssistantTemplate"], TraditionalForm]],ExpressionUUID->
  "0da885e3-2fd3-4953-954d-de196c2d052d"],
 " and the y component is given by ",
 Cell[BoxData[
  FormBox[
   TemplateBox[<|"boxes" -> FormBox[
       RowBox[{
         SubscriptBox[
          StyleBox["B", "TI"], 
          StyleBox["x", "TI"]], "\[LongEqual]", 
         StyleBox["B", "TI"], "sin", "\[Theta]"}], TraditionalForm], 
     "errors" -> {}, "input" -> "B_x=B\\sin\\theta", "state" -> "Boxes"|>,
    "TeXAssistantTemplate"], TraditionalForm]],ExpressionUUID->
  "f6c7f3c8-c88f-46db-995a-4620837009fd"],
 " assuming that we are measuring theta from the x axis. This panel should \
also make it easy to see why a vector can be expressed as a sum of two \
components that lie in the x and y directions. It doesn\[CloseCurlyQuote]t \
matter whether you got to the end of vector B by traveling directly along B, \
or by traveling along the x component followed by the y component. You are at \
the end of B either way."
}], "ItemNumbered",
 CellChangeTimes->{{3.8851378267339425`*^9, 3.885137977797906*^9}, {
  3.8851380690484805`*^9, 3.8851381448683357`*^9}, {3.885138214643474*^9, 
  3.885138279850853*^9}, {3.8851388073311157`*^9, 3.885138843484618*^9}, {
  3.8851389275585732`*^9, 3.8851391932650766`*^9}, {3.885139248850463*^9, 
  3.8851394204859486`*^9}},ExpressionUUID->"a0966969-5997-4ba5-9633-\
a89c7125b4d8"],

Cell[CellGroupData[{

Cell["\<\
Now we focus on the dot product. We want to define the dot product so that it \
multiplies parallel components together and ignores perpendicular ones. We \
would also like it to have the usual properties of multiplication (eg \
associativity, commutativity). Here is a process we might use to come up with \
a definition that fits this criteria.\
\>", "ItemNumbered",
 CellChangeTimes->{{3.8851378267339425`*^9, 3.885137977797906*^9}, {
  3.8851380690484805`*^9, 3.8851381448683357`*^9}, {3.885138214643474*^9, 
  3.885138279850853*^9}, {3.8851388073311157`*^9, 3.885138843484618*^9}, {
  3.8851389275585732`*^9, 3.8851391932650766`*^9}, {3.885139248850463*^9, 
  3.885139260479729*^9}, {3.8851394748582373`*^9, 3.885139573862048*^9}, {
  3.8851398064669952`*^9, 3.88513982526978*^9}, {3.8851404248353853`*^9, 
  3.885140458810134*^9}},ExpressionUUID->"0483d961-251c-412a-8446-\
3a9312133846"],

Cell["\<\
First look at the top left pane. What portion of Ax is parallel to Ay? Modify \
the angle that A makes and its length. You might try to find a case where Ax \
and Ay are not parallel, but this is impossible. We defined Ax and Ay to be \
the components that point along x and y respectively. They are always \
perpendicular. This means that the dot product of two component vectors along \
different axes must give 0 always.\
\>", "SubitemNumbered",
 CellChangeTimes->{{3.8851378267339425`*^9, 3.885137977797906*^9}, {
  3.8851380690484805`*^9, 3.8851381448683357`*^9}, {3.885138214643474*^9, 
  3.885138279850853*^9}, {3.8851388073311157`*^9, 3.885138843484618*^9}, {
  3.8851389275585732`*^9, 3.8851391932650766`*^9}, {3.885139248850463*^9, 
  3.885139260479729*^9}, {3.8851394748582373`*^9, 
  3.885139794911671*^9}},ExpressionUUID->"0d11ef12-38e9-4d7c-9421-\
85269dc3b49e"],

Cell[TextData[{
 "Now we recall (or learn for the first time) the definition of the unit \
vectors ",
 Cell[BoxData[
  FormBox[
   TemplateBox[<|"boxes" -> FormBox[
       RowBox[{"(", 
         RowBox[{
           OverscriptBox[
            StyleBox["x", "TI"], "^"], ",", 
           OverscriptBox[
            StyleBox["y", "TI"], "^"], ",", 
           OverscriptBox[
            StyleBox["z", "TI"], "^"]}], ")"}], TraditionalForm], 
     "errors" -> {}, "input" -> "(\\hat{x},\\hat{y},\\hat{z})", "state" -> 
     "Boxes"|>,
    "TeXAssistantTemplate"], TraditionalForm]],
  FontSize->16,ExpressionUUID->"3b15033a-b293-4d78-9520-6b10f3af63ec"],
 StyleBox[". Each of these is defined as a vector of length 1 that points \
along the chosen direction. Since our definition of the dot product asks us \
to multiply the parallel components together, the dot product must have the \
property that any unit vector dotted with itself gives 1, and any unit vector \
dotted with another unit vector gives 0. If you want to visualize the x and y \
unit vectors, set the length of A to 1.4 and the angle to 45 degrees. You \
will have the x and y unit vectors.",
  FontSize->16]
}], "SubitemNumbered",
 CellChangeTimes->{{3.8851378267339425`*^9, 3.885137977797906*^9}, {
  3.8851380690484805`*^9, 3.8851381448683357`*^9}, {3.885138214643474*^9, 
  3.885138279850853*^9}, {3.8851388073311157`*^9, 3.885138843484618*^9}, {
  3.8851389275585732`*^9, 3.8851391932650766`*^9}, {3.885139248850463*^9, 
  3.885139260479729*^9}, {3.8851394748582373`*^9, 3.885139792589862*^9}, {
  3.8851398700347652`*^9, 3.8851398916350904`*^9}, {3.885139925340475*^9, 
  3.8851399791580014`*^9}, {3.885140024016841*^9, 
  3.8851401556140594`*^9}},ExpressionUUID->"5d80dd09-ef20-4919-913c-\
42f051a4d4cf"],

Cell[TextData[{
 StyleBox["We learned earlier that any vector can be expressed in terms of \
its component vectors. Those components are just some number in some \
direction, in other words, ",
  FontSize->16],
 Cell[BoxData[
  FormBox[
   TemplateBox[<|"boxes" -> FormBox[
       RowBox[{
         OverscriptBox[
          StyleBox["A", "TI"], "\[RightVector]"], "\[LongEqual]", 
         SubscriptBox[
          StyleBox["A", "TI"], 
          StyleBox["x", "TI"]], 
         OverscriptBox[
          StyleBox["x", "TI"], "^"], "+", 
         SubscriptBox[
          StyleBox["A", "TI"], 
          StyleBox["y", "TI"]], 
         OverscriptBox[
          StyleBox["y", "TI"], "^"]}], TraditionalForm], "errors" -> {}, 
     "input" -> "\\vec{A}=A_x\\hat{x}+A_y\\hat{y}", "state" -> "Boxes"|>,
    "TeXAssistantTemplate"], TraditionalForm]],
  FontSize->16,ExpressionUUID->"324cea36-963b-4835-a0cf-2dd092c5b1b3"],
 "."
}], "SubitemNumbered",
 CellChangeTimes->{{3.8851378267339425`*^9, 3.885137977797906*^9}, {
  3.8851380690484805`*^9, 3.8851381448683357`*^9}, {3.885138214643474*^9, 
  3.885138279850853*^9}, {3.8851388073311157`*^9, 3.885138843484618*^9}, {
  3.8851389275585732`*^9, 3.8851391932650766`*^9}, {3.885139248850463*^9, 
  3.885139260479729*^9}, {3.8851394748582373`*^9, 3.885139792589862*^9}, {
  3.8851398700347652`*^9, 3.8851398916350904`*^9}, {3.885139925340475*^9, 
  3.8851399791580014`*^9}, {3.885140024016841*^9, 3.88514011127436*^9}, {
  3.8851401602999673`*^9, 3.885140228511558*^9}, {3.8851402881402225`*^9, 
  3.885140300011919*^9}, {3.8851403538978662`*^9, 
  3.885140387339883*^9}},ExpressionUUID->"54cd39bb-b24b-43e9-b27a-\
71854a520f79"],

Cell[TextData[{
 "It\[CloseCurlyQuote]s not obvious, but we actually already gave all the \
information we need to define the dot product. Consider the dot product of A \
and B. ",
 Cell[BoxData[
  FormBox[
   TemplateBox[<|"boxes" -> FormBox[
       RowBox[{
         OverscriptBox[
          StyleBox["A", "TI"], "\[RightVector]"], "\[CenterDot]", 
         OverscriptBox[
          StyleBox["B", "TI"], "\[RightVector]"], "\[LongEqual]", 
         RowBox[{"(", 
           RowBox[{
             SubscriptBox[
              StyleBox["A", "TI"], 
              StyleBox["x", "TI"]], 
             OverscriptBox[
              StyleBox["x", "TI"], "^"], "+", 
             SubscriptBox[
              StyleBox["A", "TI"], 
              StyleBox["y", "TI"]], 
             OverscriptBox[
              StyleBox["y", "TI"], "^"]}], ")"}], "\[CenterDot]", 
         RowBox[{"(", 
           RowBox[{
             SubscriptBox[
              StyleBox["B", "TI"], 
              StyleBox["x", "TI"]], 
             OverscriptBox[
              StyleBox["x", "TI"], "^"], "+", 
             SubscriptBox[
              StyleBox["B", "TI"], 
              StyleBox["y", "TI"]], 
             OverscriptBox[
              StyleBox["y", "TI"], "^"]}], ")"}], "\[LongEqual]", 
         SubscriptBox[
          StyleBox["A", "TI"], 
          StyleBox["x", "TI"]], 
         SubscriptBox[
          StyleBox["B", "TI"], 
          StyleBox["x", "TI"]], "+", 
         SubscriptBox[
          StyleBox["A", "TI"], 
          StyleBox["y", "TI"]], 
         SubscriptBox[
          StyleBox["B", "TI"], 
          StyleBox["y", "TI"]]}], TraditionalForm], "errors" -> {}, "input" -> 
     "\\vec{A}\\cdot\\vec{B}=(A_x\\hat{x}+A_y\\hat{y})\\cdot(B_x\\hat{x}+B_y\\\
hat{y})=A_xB_x+A_yB_y", "state" -> "Boxes"|>,
    "TeXAssistantTemplate"], TraditionalForm]],
  FontSize->16,ExpressionUUID->"89d8cd35-7d18-4347-a81f-1264634a5cb6"],
 ". If the second equality isn\[CloseCurlyQuote]t obvious, go ahead and \
multiply it out like regular multiplication. The only thing to remember is \
our new rule that the dot product of a unit vector with itself is 1 and the \
dot product of a unit vector with another unit vector is 0"
}], "SubitemNumbered",
 CellChangeTimes->{{3.8851378267339425`*^9, 3.885137977797906*^9}, {
  3.8851380690484805`*^9, 3.8851381448683357`*^9}, {3.885138214643474*^9, 
  3.885138279850853*^9}, {3.8851388073311157`*^9, 3.885138843484618*^9}, {
  3.8851389275585732`*^9, 3.8851391932650766`*^9}, {3.885139248850463*^9, 
  3.885139260479729*^9}, {3.8851394748582373`*^9, 3.885139792589862*^9}, {
  3.8851398700347652`*^9, 3.8851398916350904`*^9}, {3.885139925340475*^9, 
  3.8851399791580014`*^9}, {3.885140024016841*^9, 3.88514011127436*^9}, {
  3.8851401602999673`*^9, 3.885140228511558*^9}, {3.8851402881402225`*^9, 
  3.885140300011919*^9}, {3.8851403538978662`*^9, 3.8851404183055024`*^9}, {
  3.885140466184702*^9, 3.8851404979637575`*^9}, {3.8851406028453407`*^9, 
  3.885140618255661*^9}, {3.885140678069008*^9, 3.885140759255723*^9}, {
  3.885141668379378*^9, 
  3.8851416748593507`*^9}},ExpressionUUID->"e2021221-2778-46fe-853f-\
f790b25a0ddd"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Now we want to visualize this and see what we can learn. ", \
"ItemNumbered",
 CellChangeTimes->{{3.8851378267339425`*^9, 3.885137977797906*^9}, {
  3.8851380690484805`*^9, 3.8851381448683357`*^9}, {3.885138214643474*^9, 
  3.885138279850853*^9}, {3.8851388073311157`*^9, 3.885138843484618*^9}, {
  3.8851389275585732`*^9, 3.8851391932650766`*^9}, {3.885139248850463*^9, 
  3.885139260479729*^9}, {3.8851394748582373`*^9, 3.885139792589862*^9}, {
  3.8851398700347652`*^9, 3.8851398916350904`*^9}, {3.885139925340475*^9, 
  3.8851399791580014`*^9}, {3.885140024016841*^9, 3.88514011127436*^9}, {
  3.8851401602999673`*^9, 3.885140228511558*^9}, {3.8851402881402225`*^9, 
  3.885140300011919*^9}, {3.8851403538978662`*^9, 3.8851404183055024`*^9}, {
  3.885140466184702*^9, 3.885140479217759*^9}, {3.8851407699685965`*^9, 
  3.8851408775962267`*^9}, {3.885140988916291*^9, 
  3.8851409889172835`*^9}},ExpressionUUID->"10aa6de6-6f66-4ea6-83d6-\
0a7342762339"],

Cell["\<\
Play with the values of A and B and watch the top right pane. What can you do \
to make the dot product as large as possible? When is the dot product \
negative? How can you relate that with the definition given earlier?\
\>", "SubitemNumbered",
 CellChangeTimes->{{3.8851378267339425`*^9, 3.885137977797906*^9}, {
  3.8851380690484805`*^9, 3.8851381448683357`*^9}, {3.885138214643474*^9, 
  3.885138279850853*^9}, {3.8851388073311157`*^9, 3.885138843484618*^9}, {
  3.8851389275585732`*^9, 3.8851391932650766`*^9}, {3.885139248850463*^9, 
  3.885139260479729*^9}, {3.8851394748582373`*^9, 3.885139792589862*^9}, {
  3.8851398700347652`*^9, 3.8851398916350904`*^9}, {3.885139925340475*^9, 
  3.8851399791580014`*^9}, {3.885140024016841*^9, 3.88514011127436*^9}, {
  3.8851401602999673`*^9, 3.885140228511558*^9}, {3.8851402881402225`*^9, 
  3.885140300011919*^9}, {3.8851403538978662`*^9, 3.8851404183055024`*^9}, {
  3.885140466184702*^9, 3.885140479217759*^9}, {3.8851407699685965`*^9, 
  3.8851408775962267`*^9}},ExpressionUUID->"73c485a6-9397-416d-b354-\
d08a4004e188"],

Cell["\<\
You hopefully noticed that the dot product is largest when the vectors point \
in the same direction and that the further apart that the vectors point, the \
smaller the product gets. This might already be a hint that the dot product \
has something to do with cosine, but we would like to elucidate this more.\
\>", "SubitemNumbered",
 CellChangeTimes->{{3.8851378267339425`*^9, 3.885137977797906*^9}, {
  3.8851380690484805`*^9, 3.8851381448683357`*^9}, {3.885138214643474*^9, 
  3.885138279850853*^9}, {3.8851388073311157`*^9, 3.885138843484618*^9}, {
  3.8851389275585732`*^9, 3.8851391932650766`*^9}, {3.885139248850463*^9, 
  3.885139260479729*^9}, {3.8851394748582373`*^9, 3.885139792589862*^9}, {
  3.8851398700347652`*^9, 3.8851398916350904`*^9}, {3.885139925340475*^9, 
  3.8851399791580014`*^9}, {3.885140024016841*^9, 3.88514011127436*^9}, {
  3.8851401602999673`*^9, 3.885140228511558*^9}, {3.8851402881402225`*^9, 
  3.885140300011919*^9}, {3.8851403538978662`*^9, 3.8851404183055024`*^9}, {
  3.885140466184702*^9, 3.885140479217759*^9}, {3.8851407699685965`*^9, 
  3.8851409932557917`*^9}},ExpressionUUID->"1f3d6d71-53da-444d-871f-\
59226ae87314"],

Cell["\<\
Play with A and B. Notice that, unless the vectors lie in the same quadrant, \
there is some component of each vector that points in a direction opposite \
the corresponding component of the other vector (eg maybe Ax points right and \
Bx points left). This, results from the sign changes that sine and cosine \
undergo as you change quadrants.\
\>", "SubitemNumbered",
 CellChangeTimes->{{3.8851378267339425`*^9, 3.885137977797906*^9}, {
  3.8851380690484805`*^9, 3.8851381448683357`*^9}, {3.885138214643474*^9, 
  3.885138279850853*^9}, {3.8851388073311157`*^9, 3.885138843484618*^9}, {
  3.8851389275585732`*^9, 3.8851391932650766`*^9}, {3.885139248850463*^9, 
  3.885139260479729*^9}, {3.8851394748582373`*^9, 3.885139792589862*^9}, {
  3.8851398700347652`*^9, 3.8851398916350904`*^9}, {3.885139925340475*^9, 
  3.8851399791580014`*^9}, {3.885140024016841*^9, 3.88514011127436*^9}, {
  3.8851401602999673`*^9, 3.885140228511558*^9}, {3.8851402881402225`*^9, 
  3.885140300011919*^9}, {3.8851403538978662`*^9, 3.8851404183055024`*^9}, {
  3.885140466184702*^9, 3.885140479217759*^9}, {3.8851407699685965`*^9, 
  3.8851409975256805`*^9}, {3.8851410340720778`*^9, 3.8851411046917906`*^9}, {
  3.8851411493123465`*^9, 
  3.8851411797808886`*^9}},ExpressionUUID->"ad4e93c8-064b-4b43-b060-\
63427bf7ca6f"],

Cell["\<\
Now set the vectors so that they appear to be about 90 degrees apart. You \
should notice that the dot product is 0. You can try this a few times until \
you are convinced that this happens for all possible combinations of A and B \
that result in perpendicular vectors. Now measure the components of each \
vector and manually compute the dot product. You should get 0.\
\>", "SubitemNumbered",
 CellChangeTimes->{{3.8851378267339425`*^9, 3.885137977797906*^9}, {
  3.8851380690484805`*^9, 3.8851381448683357`*^9}, {3.885138214643474*^9, 
  3.885138279850853*^9}, {3.8851388073311157`*^9, 3.885138843484618*^9}, {
  3.8851389275585732`*^9, 3.8851391932650766`*^9}, {3.885139248850463*^9, 
  3.885139260479729*^9}, {3.8851394748582373`*^9, 3.885139792589862*^9}, {
  3.8851398700347652`*^9, 3.8851398916350904`*^9}, {3.885139925340475*^9, 
  3.8851399791580014`*^9}, {3.885140024016841*^9, 3.88514011127436*^9}, {
  3.8851401602999673`*^9, 3.885140228511558*^9}, {3.8851402881402225`*^9, 
  3.885140300011919*^9}, {3.8851403538978662`*^9, 3.8851404183055024`*^9}, {
  3.885140466184702*^9, 3.885140479217759*^9}, {3.8851407699685965`*^9, 
  3.8851409975256805`*^9}, {3.8851410340720778`*^9, 3.8851411046917906`*^9}, {
  3.8851411493123465`*^9, 3.8851411788143797`*^9}, {3.885141276549413*^9, 
  3.8851414108499327`*^9}},ExpressionUUID->"3320587b-5936-43a0-be0d-\
ca78cb325379"],

Cell[TextData[{
 "Now, multiply out the dot product ",
 Cell[BoxData[
  FormBox[
   TemplateBox[<|"boxes" -> FormBox[
       RowBox[{
         OverscriptBox[
          StyleBox["A", "TI"], "\[RightVector]"], "\[CenterDot]", 
         OverscriptBox[
          StyleBox["B", "TI"], "\[RightVector]"], "\[LongEqual]", 
         RowBox[{"(", 
           RowBox[{
             SubscriptBox[
              StyleBox["A", "TI"], 
              StyleBox["x", "TI"]], 
             OverscriptBox[
              StyleBox["x", "TI"], "^"], "+", 
             SubscriptBox[
              StyleBox["A", "TI"], 
              StyleBox["y", "TI"]], 
             OverscriptBox[
              StyleBox["y", "TI"], "^"]}], ")"}], "\[CenterDot]", 
         RowBox[{"(", 
           RowBox[{
             SubscriptBox[
              StyleBox["B", "TI"], 
              StyleBox["x", "TI"]], 
             OverscriptBox[
              StyleBox["x", "TI"], "^"], "+", 
             SubscriptBox[
              StyleBox["B", "TI"], 
              StyleBox["y", "TI"]], 
             OverscriptBox[
              StyleBox["y", "TI"], "^"]}], ")"}], "\[LongEqual]", 
         SubscriptBox[
          StyleBox["A", "TI"], 
          StyleBox["x", "TI"]], 
         SubscriptBox[
          StyleBox["B", "TI"], 
          StyleBox["x", "TI"]], "+", 
         SubscriptBox[
          StyleBox["A", "TI"], 
          StyleBox["y", "TI"]], 
         SubscriptBox[
          StyleBox["B", "TI"], 
          StyleBox["y", "TI"]]}], TraditionalForm], "errors" -> {}, "input" -> 
     "\\vec{A}\\cdot\\vec{B}=(A_x\\hat{x}+A_y\\hat{y})\\cdot(B_x\\hat{x}+B_y\\\
hat{y})=A_xB_x+A_yB_y", "state" -> "Boxes"|>,
    "TeXAssistantTemplate"], TraditionalForm]],ExpressionUUID->
  "03d90c7e-6028-4109-925f-e19b506127da"],
 " remembering that ",
 Cell[BoxData[
  FormBox[
   TemplateBox[<|"boxes" -> FormBox[
       RowBox[{
         SubscriptBox[
          StyleBox["A", "TI"], 
          StyleBox["x", "TI"]], "\[LongEqual]", 
         StyleBox["A", "TI"], "cos", 
         SubscriptBox["\[Theta]", "1"]}], TraditionalForm], "errors" -> {}, 
     "input" -> "A_x=A\\cos\\theta_1", "state" -> "Boxes"|>,
    "TeXAssistantTemplate"], TraditionalForm]],ExpressionUUID->
  "dc10dadd-421f-4e89-bdd5-3a02ae9971e5"],
 " and so on. Together with the add angle formula for cosine, you should be \
able to show that ",
 Cell[BoxData[
  FormBox[
   TemplateBox[<|"boxes" -> FormBox[
       RowBox[{
         OverscriptBox[
          StyleBox["A", "TI"], "\[RightVector]"], "\[CenterDot]", 
         OverscriptBox[
          StyleBox["B", "TI"], "\[RightVector]"], "\[LongEqual]", 
         StyleBox["A", "TI"], 
         StyleBox["B", "TI"], "cos", 
         SubscriptBox["\[Theta]", 
          RowBox[{
            StyleBox["A", "TI"], 
            StyleBox["B", "TI"]}]]}], TraditionalForm], "errors" -> {}, 
     "input" -> "\\vec{A}\\cdot\\vec{B}=AB\\cos\\theta_{AB}", "state" -> 
     "Boxes"|>,
    "TeXAssistantTemplate"], TraditionalForm]],ExpressionUUID->
  "423f25f8-9b4d-4a02-81dc-2505ee0b0e99"],
 " where ",
 Cell[BoxData[
  FormBox[
   TemplateBox[<|"boxes" -> FormBox[
       SubscriptBox["\[Theta]", 
        RowBox[{
          StyleBox["A", "TI"], 
          StyleBox["B", "TI"]}]], TraditionalForm], "errors" -> {}, "input" -> 
     "\\theta_{AB}", "state" -> "Boxes"|>,
    "TeXAssistantTemplate"], TraditionalForm]],ExpressionUUID->
  "ee6bd7a8-c873-46ed-8d70-4ea20f231eff"],
 " is the angle between A and B. Thus, the dot product is deeply related to \
the cosine of an angle."
}], "SubitemNumbered",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQAWIQXVoT/sX/0xvHog5L9gAgrd67UAhEZ5yUlgHR4dOv
qIBoA6vfOiC6YcarPBD9rzG/GERfvf+xFkQ3VWvMB4ubSS8D0R8j+5eD6HVl
0YdAtNoDoVcg+ozMwc8gemVQyTcQrfN01S8QHcmXyhgIpL91MrCD6P7jLwRB
dOhMTgkQvT5uggKI3lLDogGilyQ2aILooN02BiB67TFPCxAt8tLVDkQ/+v7M
HkTv+2eXAqITLm1oANFlfk6tIFpNWawPIr9yMohO44+aDqJPT5m4GER/eemw
BUSXui08C6LtgiMvgugZBpLXQPSk0sUfQTQAWbKypA==
  "],ExpressionUUID->"68eb976f-3366-4ec5-8f96-37a6cf463628"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Finally we look at the cross product. The cross product will be defined so \
that ",
 Cell[BoxData[
  FormBox[
   TemplateBox[<|"boxes" -> FormBox[
       RowBox[{
         OverscriptBox[
          StyleBox["A", "TI"], "\[RightVector]"], "\[Cross]", 
         OverscriptBox[
          StyleBox["B", "TI"], "\[RightVector]"]}], TraditionalForm], 
     "errors" -> {}, "input" -> "\\vec{A}\\times\\vec{B}", "state" -> "Boxes"|>,
    "TeXAssistantTemplate"], TraditionalForm]],ExpressionUUID->
  "fe36fe66-538d-41ea-a5f4-8346a5621b84"],
 " returns a vector perpendicular to both A and B. If you want to know why \
the cross product should return a vector instead of a scalar, there are some \
good reasons that come from more advanced math, but for now, we just defined \
it that way. Play with the simulations until you convince yourself that no \
vector in the x-y plane is perpendicular to both A and B.  Fortunately, such \
a vector does exist. We know that the z direction is perpendicular to both x \
and y. The only question is whether we should pick positive z or negative z. \
We adopt a (completely arbitrary) convention that each of these equalities \
should hold. "
}], "ItemNumbered",
 CellChangeTimes->{{3.8851378267339425`*^9, 3.885137977797906*^9}, {
   3.8851380690484805`*^9, 3.8851381448683357`*^9}, {3.885138214643474*^9, 
   3.885138279850853*^9}, {3.8851388073311157`*^9, 3.885138843484618*^9}, {
   3.8851389275585732`*^9, 3.8851391932650766`*^9}, {3.885139248850463*^9, 
   3.885139260479729*^9}, {3.8851394748582373`*^9, 3.885139792589862*^9}, {
   3.8851398700347652`*^9, 3.8851398916350904`*^9}, {3.885139925340475*^9, 
   3.8851399791580014`*^9}, {3.885140024016841*^9, 3.88514011127436*^9}, {
   3.8851401602999673`*^9, 3.885140228511558*^9}, {3.8851402881402225`*^9, 
   3.885140300011919*^9}, {3.8851403538978662`*^9, 3.8851404183055024`*^9}, {
   3.885140466184702*^9, 3.885140479217759*^9}, {3.8851407699685965`*^9, 
   3.8851409975256805`*^9}, {3.8851410340720778`*^9, 
   3.8851411046917906`*^9}, {3.8851411493123465`*^9, 
   3.8851411788143797`*^9}, {3.885141276549413*^9, 3.8851414100285587`*^9}, {
   3.8851416130398507`*^9, 3.8851416427914114`*^9}, {3.885141680787182*^9, 
   3.885141897607396*^9}, {3.8851429837584524`*^9, 3.8851431543598948`*^9}, {
   3.885143189654606*^9, 3.88514338874347*^9}, {3.8851434783087835`*^9, 
   3.885143499285164*^9}, 
   3.885143543751627*^9},ExpressionUUID->"305641db-844a-4453-9221-\
f89852783da7"],

Cell[CellGroupData[{

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   TemplateBox[<|"boxes" -> FormBox[
       RowBox[{
         OverscriptBox[
          StyleBox["x", "TI"], "^"], "\[Cross]", 
         OverscriptBox[
          StyleBox["y", "TI"], "^"], "\[LongEqual]", 
         OverscriptBox[
          StyleBox["z", "TI"], "^"]}], TraditionalForm], "errors" -> {}, 
     "input" -> "\\hat{x}\\times \\hat{y}=\\hat{z}", "state" -> "Boxes"|>,
    "TeXAssistantTemplate"], ",", "  ", 
   TemplateBox[<|"boxes" -> FormBox[
       RowBox[{
         OverscriptBox[
          StyleBox["y", "TI"], "^"], "\[Cross]", 
         OverscriptBox[
          StyleBox["x", "TI"], "^"]}], TraditionalForm], "errors" -> {}, 
     "input" -> "\\hat{y}\\times \\hat{x}", "state" -> "Boxes"|>,
    "TeXAssistantTemplate"]}], 
  TraditionalForm]],ExpressionUUID->"852735d7-b30c-4686-86ad-320607da2772"]], \
"SubitemNumbered",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQB2IQXVoT/sX/0xvHog5L9gAgrd67UAhEZ5yUlgHR4dOv
qIBoA6vfOiC6YcarPBD9rzG/GERfvf+xFkQ3VWvMB4ubSS8D0R8j+5eD6HVl
0YdAtNoDoVcg+ozMwc8gemVQyTcQrfN01S8QHcmXyhgIpL91MrCD6P7jLwRB
dOhMTgkQvT5uggKI3lLDogGilyQ2aILooN02BiB67TFPCxAt8tLVDkQ/+v7M
HkTv+2eXAqITLm1oANFlfk6tIFpNWawPIr9yMohO44+aDqJPT5m4GER/eemw
BUSXui08C6LtgiMvgugZBpLXQPSpfOOPYHHXHxVBQNqpxbsPRHd82jIJRO/J
X7oGRJuLqmwE0T/eSWwC0QBiVM2u
  "],ExpressionUUID->"463acadd-c4a7-43bd-a97e-e690c76251ee"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"firstCell", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CloseCodeCells", "[", "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "cells", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"cells", "=", 
        RowBox[{
         RowBox[{"Cells", "[", 
          RowBox[{"CellStyle", "->", "\"\<Input\>\""}], "]"}], "[", 
         RowBox[{"[", 
          RowBox[{"firstCell", ";;", 
           RowBox[{"-", "1"}]}], "]"}], "]"}]}], ";", 
       RowBox[{
        RowBox[{
         RowBox[{"SetOptions", "[", 
          RowBox[{"#", ",", 
           RowBox[{"CellOpen", "->", "False"}]}], "]"}], "&"}], "/@", 
        "cells"}], ";"}]}], "]"}]}], ";"}], "\[IndentingNewLine]"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"OpenCodeCells", "[", "]"}], ":=", 
    RowBox[{"Module", "[", 
     RowBox[{
      RowBox[{"{", "cells", "}"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"cells", "=", 
        RowBox[{
         RowBox[{"Cells", "[", 
          RowBox[{"CellStyle", "->", "\"\<Input\>\""}], "]"}], "[", 
         RowBox[{"[", 
          RowBox[{"1", ";;", 
           RowBox[{"-", "1"}]}], "]"}], "]"}]}], ";", 
       RowBox[{
        RowBox[{
         RowBox[{"SetOptions", "[", 
          RowBox[{"#", ",", 
           RowBox[{"CellOpen", "->", "True"}]}], "]"}], "&"}], "/@", 
        "cells"}], ";"}]}], "]"}]}], ";"}], "\[IndentingNewLine]"}], "\n", 
 RowBox[{"Row", "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Button", "[", 
     RowBox[{"\"\<Open Code\>\"", ",", 
      RowBox[{"SelectionEvaluate", "[", 
       RowBox[{"OpenCodeCells", "[", "]"}], "]"}]}], "]"}], ",", 
    RowBox[{"Button", "[", 
     RowBox[{"\"\<Close Code\>\"", ",", 
      RowBox[{"SelectionEvaluate", "[", 
       RowBox[{"CloseCodeCells", "[", "]"}], "]"}]}], "]"}]}], "}"}], 
  "]"}]}], "Input",
 CellOpen->False,
 CellLabel->
  "In[290]:=",ExpressionUUID->"484668f7-9a5a-4b04-8545-5f109ab7cb60"],

Cell[BoxData[
 TemplateBox[{
   ButtonBox["\"Open Code\"", ButtonFunction :> SelectionEvaluate[
      $CellContext`OpenCodeCells[]], Appearance -> Automatic, Evaluator -> 
    Automatic, Method -> "Preemptive"], 
   ButtonBox["\"Close Code\"", ButtonFunction :> SelectionEvaluate[
      $CellContext`CloseCodeCells[]], Appearance -> Automatic, Evaluator -> 
    Automatic, Method -> "Preemptive"]},
  "RowDefault"]], "Output",
 CellChangeTimes->{3.885131812845508*^9, 3.8851336268856645`*^9, 
  3.8851336671980515`*^9, 3.885133787176092*^9, 3.8851339938061867`*^9, 
  3.8851366025661726`*^9, 3.8851369373004932`*^9, 3.8851369829850836`*^9},
 CellLabel->
  "Out[293]=",ExpressionUUID->"322887f6-c45e-489a-b4cb-0674b6b16387"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "rad", ",", "Ax", ",", "Ay", ",", "Bx", ",", "By", ",", "LabeledArrow", 
       ",", "LabeledArrow2", ",", "Avec", ",", "Bvec", ",", "vecGraphic", ",",
        "xComponent", ",", "yComponent", ",", "Agraphic", ",", "Bgraphic", 
       ",", "ShiftedBy", ",", "\[IndentingNewLine]", "ShiftedyComponent"}], 
      "}"}], ",", 
     RowBox[{
      RowBox[{
       RowBox[{"rad", "[", "\[Gamma]_", "]"}], ":=", 
       RowBox[{"\[Gamma]", "*", 
        RowBox[{"Pi", "/", "180"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"LabeledArrow", "[", 
        RowBox[{"p_", ",", "q_", ",", "label_"}], "]"}], ":=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Arrowheads", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.035"}], ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.014"}], ",", "0.5", ",", 
              RowBox[{"Graphics", "[", 
               RowBox[{"Inset", "[", 
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"label", ",", "Small"}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"Center", ",", "Top"}], "}"}]}], "]"}], "]"}]}], 
             "}"}]}], "}"}], "]"}], ",", 
         RowBox[{"Arrow", "[", 
          RowBox[{"{", 
           RowBox[{"q", ",", "p"}], "}"}], "]"}]}], "}"}]}], " ", ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"LabeledArrow2", "[", 
        RowBox[{"p_", ",", "q_", ",", "label_"}], "]"}], ":=", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Arrowheads", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"-", "0.035"}], ",", "0"}], "}"}], ",", 
            RowBox[{"{", 
             RowBox[{"0.014", ",", "0.5", ",", 
              RowBox[{"Graphics", "[", 
               RowBox[{"Inset", "[", 
                RowBox[{
                 RowBox[{"Style", "[", 
                  RowBox[{"label", ",", "Small"}], "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"Center", ",", "Top"}], "}"}]}], "]"}], "]"}]}], 
             "}"}]}], "}"}], "]"}], ",", 
         RowBox[{"Arrow", "[", 
          RowBox[{"{", 
           RowBox[{"q", ",", "p"}], "}"}], "]"}]}], "}"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"vecGraphic", "[", 
        RowBox[{"L_", ",", "\[Theta]_", ",", "Label_String"}], "]"}], ":=", 
       RowBox[{"Module", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"x", ",", "y"}], "}"}], ",", 
         RowBox[{
          RowBox[{"x", "=", 
           RowBox[{"L", "*", 
            RowBox[{"Cos", "[", 
             RowBox[{"rad", "[", "\[Theta]", "]"}], "]"}]}]}], ";", 
          RowBox[{"y", "=", 
           RowBox[{"L", "*", 
            RowBox[{"Sin", "[", 
             RowBox[{"rad", "[", "\[Theta]", "]"}], "]"}]}]}], ";", 
          RowBox[{"Return", "[", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"Or", "[", 
              RowBox[{
               RowBox[{"\[Theta]", "<", "90"}], ",", 
               RowBox[{"\[Theta]", ">", "270"}]}], "]"}], ",", 
             RowBox[{"LabeledArrow", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"0", ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"x", ",", "y"}], "}"}], ",", "Label"}], "]"}], ",", 
             RowBox[{"LabeledArrow2", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"0", ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"x", ",", "y"}], "}"}], ",", "Label"}], "]"}]}], 
            "]"}], "]"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"ShiftedyComponent", "[", 
        RowBox[{"L_", ",", "\[Theta]_", ",", "Label_String"}], "]"}], ":=", 
       RowBox[{"Module", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"x", ",", "y"}], "}"}], ",", 
         RowBox[{
          RowBox[{"x", "=", 
           RowBox[{"L", "*", 
            RowBox[{"Cos", "[", 
             RowBox[{"rad", "[", "\[Theta]", "]"}], "]"}]}]}], ";", 
          RowBox[{"y", "=", 
           RowBox[{"L", "*", 
            RowBox[{"Sin", "[", 
             RowBox[{"rad", "[", "\[Theta]", "]"}], "]"}]}]}], ";", 
          RowBox[{"Return", "[", 
           RowBox[{"If", "[", 
            RowBox[{
             RowBox[{"Or", "[", 
              RowBox[{
               RowBox[{"\[Theta]", "<", "90"}], ",", 
               RowBox[{"\[Theta]", ">", "270"}]}], "]"}], ",", 
             RowBox[{"LabeledArrow", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"x", ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"x", ",", "y"}], "}"}], ",", "Label"}], "]"}], ",", 
             RowBox[{"LabeledArrow2", "[", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"x", ",", "0"}], "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"x", ",", "y"}], "}"}], ",", "Label"}], "]"}]}], 
            "]"}], "]"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"xComponent", "[", 
        RowBox[{"L_", ",", "\[Theta]_", ",", "Label_String"}], "]"}], ":=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"Or", "[", 
          RowBox[{
           RowBox[{"\[Theta]", "<", "90"}], ",", 
           RowBox[{"\[Theta]", ">", "270"}]}], "]"}], ",", 
         RowBox[{"vecGraphic", "[", 
          RowBox[{
           RowBox[{"L", "*", 
            RowBox[{"Cos", "[", 
             RowBox[{"rad", "[", "\[Theta]", "]"}], "]"}]}], ",", "0", ",", 
           "Label"}], "]"}], ",", 
         RowBox[{"vecGraphic", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "L"}], "*", 
            RowBox[{"Cos", "[", 
             RowBox[{"rad", "[", "\[Theta]", "]"}], "]"}]}], ",", "180", ",", 
           "Label"}], "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"yComponent", "[", 
        RowBox[{"L_", ",", "\[Theta]_", ",", "Label_String"}], "]"}], ":=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"\[Theta]", "<", "180"}], ",", 
         RowBox[{"vecGraphic", "[", 
          RowBox[{
           RowBox[{"L", "*", 
            RowBox[{"Sin", "[", 
             RowBox[{"rad", "[", "\[Theta]", "]"}], "]"}]}], ",", "90", ",", 
           "Label"}], "]"}], ",", 
         RowBox[{"vecGraphic", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "L"}], "*", 
            RowBox[{"Sin", "[", 
             RowBox[{"rad", "[", "\[Theta]", "]"}], "]"}]}], ",", "270", ",", 
           "Label"}], "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Agraphic", "=", 
       RowBox[{"vecGraphic", "[", 
        RowBox[{"La", ",", "\[Theta]a", ",", "\"\<A\>\""}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Bgraphic", "=", 
       RowBox[{"vecGraphic", "[", 
        RowBox[{"Lb", ",", "\[Theta]b", ",", "\"\<B\>\""}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Ax", "=", 
       RowBox[{"xComponent", "[", 
        RowBox[{"La", ",", "\[Theta]a", ",", "\"\<Ax\>\""}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Ay", "=", 
       RowBox[{"yComponent", "[", 
        RowBox[{"La", ",", "\[Theta]a", ",", "\"\<Ay\>\""}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Bx", "=", 
       RowBox[{"xComponent", "[", 
        RowBox[{"Lb", ",", "\[Theta]b", ",", "\"\<Bx\>\""}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"By", "=", 
       RowBox[{"yComponent", "[", 
        RowBox[{"Lb", ",", "\[Theta]b", ",", "\"\<By\>\""}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Avec", "=", 
       RowBox[{"La", "*", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"rad", "[", "\[Theta]a", "]"}], "]"}], ",", 
          RowBox[{"Sin", "[", 
           RowBox[{"rad", "[", "\[Theta]a", "]"}], "]"}]}], "}"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Bvec", "=", 
       RowBox[{"Lb", "*", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"Cos", "[", 
           RowBox[{"rad", "[", "\[Theta]b", "]"}], "]"}], ",", 
          RowBox[{"Sin", "[", 
           RowBox[{"rad", "[", "\[Theta]b", "]"}], "]"}]}], "}"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"ShiftedBy", "=", 
       RowBox[{"ShiftedyComponent", "[", 
        RowBox[{"Lb", ",", "\[Theta]b", ",", "\"\<By\>\""}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Row", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Column", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"\"\<Vector A decomposition\>\"", ",", "Bold"}], "]"}], 
            ",", 
            RowBox[{"Graphics", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"Thick", ",", "Red", ",", "Agraphic", ",", 
                RowBox[{"Darker", "@", "Red"}], ",", "Thick", ",", "Ax", ",", 
                RowBox[{"Lighter", "@", "Red"}], ",", "Ay"}], "}"}], ",", 
              RowBox[{"PlotRange", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"-", "3"}], ",", "3"}], "}"}]}], "}"}]}], ",", 
              RowBox[{"ImageSize", "->", " ", "Medium"}], ",", " ", 
              RowBox[{"Axes", "->", "True"}]}], "]"}], ",", 
            RowBox[{"Style", "[", 
             RowBox[{"\"\<Vector B decomposition\>\"", ",", "Bold"}], "]"}], 
            ",", 
            RowBox[{"Graphics", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{"Thick", ",", "Blue", ",", "Bgraphic", ",", 
                RowBox[{"Darker", "@", "Blue"}], ",", "Thick", ",", "Bx", ",", 
                RowBox[{"Lighter", "@", "Blue"}], ",", "By", ",", " ", 
                "Thick", ",", " ", 
                RowBox[{"Lighter", "@", "Blue"}], ",", "Dashed", ",", 
                "ShiftedBy"}], "}"}], ",", 
              RowBox[{"PlotRange", "\[Rule]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"-", "3"}], ",", "3"}], "}"}]}], "}"}]}], ",", 
              RowBox[{"ImageSize", "->", " ", "Medium"}], ",", 
              RowBox[{"Axes", "->", "True"}]}], "]"}]}], "}"}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"Column", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"Style", "[", 
             RowBox[{"\"\<                  Dot Product\>\"", ",", "Bold"}], 
             "]"}], ",", 
            RowBox[{"Labeled", "[", 
             RowBox[{
              RowBox[{"Graphics", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"Thick", ",", "Red", ",", "Agraphic", ",", 
                  RowBox[{"Darker", "@", "Red"}], ",", "Thick", ",", "Ax", 
                  ",", 
                  RowBox[{"Lighter", "@", "Red"}], ",", "Ay", ",", "Thick", 
                  ",", "Blue", ",", "Bgraphic", ",", 
                  RowBox[{"Darker", "@", "Blue"}], ",", "Thick", ",", "Bx", 
                  ",", 
                  RowBox[{"Lighter", "@", "Blue"}], ",", "By"}], "}"}], ",", 
                RowBox[{"PlotRange", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "3"}], ",", "3"}], "}"}]}], "}"}]}], ",", 
                RowBox[{"ImageSize", "->", " ", "Medium"}], ",", 
                RowBox[{"Axes", "->", "True"}]}], "]"}], ",", 
              "\[IndentingNewLine]", 
              RowBox[{"Grid", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Spacer", "[", "0.1", "]"}], ",", 
                   RowBox[{"Style", "[", 
                    RowBox[{"\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
RowBox[{
SubscriptBox[
StyleBox[\"A\", \"TI\"], 
StyleBox[\"x\", \"TI\"]], \"\[LongEqual]\"}], TraditionalForm], \"errors\" -> \
{}, \"input\" -> \"A_x=\", \"state\" -> \"Boxes\"|>,\"TeXAssistantTemplate\"]\
\)\>\"", ",", "14"}], "]"}], ",", 
                   RowBox[{"Round", "[", 
                    RowBox[{
                    RowBox[{"Avec", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", "0.01"}], "]"}], ",", 
                   RowBox[{"Spacer", "[", "0.5", "]"}], ",", 
                   RowBox[{"Style", "[", 
                    RowBox[{"\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
RowBox[{
SubscriptBox[
StyleBox[\"A\", \"TI\"], 
StyleBox[\"y\", \"TI\"]], \"\[LongEqual]\"}], TraditionalForm], \"errors\" -> \
{}, \"input\" -> \"A_y=\", \"state\" -> \"Boxes\"|>,\"TeXAssistantTemplate\"]\
\)\>\"", ",", "14"}], "]"}], ",", 
                   RowBox[{"Round", "[", 
                    RowBox[{
                    RowBox[{"Avec", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ",", "0.01"}], "]"}]}], 
                  "}"}], ",", "\[IndentingNewLine]", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Spacer", "[", "0.1", "]"}], ",", 
                   RowBox[{"Style", "[", 
                    RowBox[{"\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
RowBox[{
SubscriptBox[
StyleBox[\"B\", \"TI\"], 
StyleBox[\"x\", \"TI\"]], \"\[LongEqual]\"}], TraditionalForm], \"errors\" -> \
{}, \"input\" -> \"B_x=\", \"state\" -> \"Boxes\"|>,\"TeXAssistantTemplate\"]\
\)\>\"", ",", "14"}], "]"}], ",", 
                   RowBox[{"Round", "[", 
                    RowBox[{
                    RowBox[{"Bvec", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", "0.01"}], "]"}], ",", 
                   RowBox[{"Spacer", "[", "0.2", "]"}], ",", 
                   RowBox[{"Style", "[", 
                    RowBox[{"\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
RowBox[{
SubscriptBox[
StyleBox[\"B\", \"TI\"], 
StyleBox[\"y\", \"TI\"]], \"\[LongEqual]\"}], TraditionalForm], \"errors\" -> \
{}, \"input\" -> \"B_y=\", \"state\" -> \"Boxes\"|>,\"TeXAssistantTemplate\"]\
\)\>\"", ",", "14"}], "]"}], ",", 
                   RowBox[{"Round", "[", 
                    RowBox[{
                    RowBox[{"Bvec", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ",", "0.01"}], "]"}], ",", 
                   RowBox[{"Spacer", "[", "0.9", "]"}]}], "}"}], ",", 
                 "\[IndentingNewLine]", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Spacer", "[", "0.1", "]"}], ",", 
                   RowBox[{"Style", "[", 
                    RowBox[{"\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
RowBox[{
SubscriptBox[
StyleBox[\"A\", \"TI\"], 
StyleBox[\"x\", \"TI\"]], 
SubscriptBox[
StyleBox[\"B\", \"TI\"], 
StyleBox[\"x\", \"TI\"]], \"\[LongEqual]\"}], TraditionalForm], \"errors\" -> \
{}, \"input\" -> \"A_xB_x=\", \"state\" -> \"Boxes\"|>,\"TeXAssistantTemplate\
\"]\)\>\"", ",", "14"}], "]"}], ",", 
                   RowBox[{"Round", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Avec", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "*", 
                    RowBox[{"Bvec", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], ",", "0.01"}], "]"}], 
                   ",", 
                   RowBox[{"Spacer", "[", "0.5", "]"}], ",", 
                   RowBox[{"Style", "[", 
                    RowBox[{"\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
RowBox[{
SubscriptBox[
StyleBox[\"A\", \"TI\"], 
StyleBox[\"y\", \"TI\"]], 
SubscriptBox[
StyleBox[\"B\", \"TI\"], 
StyleBox[\"y\", \"TI\"]], \"\[LongEqual]\"}], TraditionalForm], \"errors\" -> \
{}, \"input\" -> \"A_yB_y=\", \"state\" -> \"Boxes\"|>,\"TeXAssistantTemplate\
\"]\)\>\"", ",", "14"}], "]"}], ",", 
                   RowBox[{"Round", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Avec", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "*", 
                    RowBox[{"Bvec", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], ",", "0.01"}], "]"}]}], 
                  "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Style", "[", 
                    RowBox[{"\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
RowBox[{
OverscriptBox[
StyleBox[\"A\", \"TI\"], \"\[RightVector]\"], \"\[CenterDot]\", 
OverscriptBox[
StyleBox[\"B\", \"TI\"], \"\[RightVector]\"], \"\[LongEqual]\", 
SubscriptBox[
StyleBox[\"A\", \"TI\"], 
StyleBox[\"x\", \"TI\"]], 
SubscriptBox[
StyleBox[\"B\", \"TI\"], 
StyleBox[\"x\", \"TI\"]], \"+\", 
SubscriptBox[
StyleBox[\"A\", \"TI\"], 
StyleBox[\"y\", \"TI\"]], 
SubscriptBox[
StyleBox[\"B\", \"TI\"], 
StyleBox[\"y\", \"TI\"]]}], TraditionalForm], \"errors\" -> {}, \"input\" -> \
\"\\\\vec{A}\\\\cdot \\\\vec{B}=A_xB_x+A_yB_y\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\"", ",", "14"}], "]"}], ",", 
                   RowBox[{"Spacer", "[", "0.1", "]"}], ",", 
                   RowBox[{"Style", "[", 
                    RowBox[{"\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
RowBox[{
OverscriptBox[
StyleBox[\"A\", \"TI\"], \"\[RightVector]\"], \"\[CenterDot]\", 
OverscriptBox[
StyleBox[\"B\", \"TI\"], \"\[RightVector]\"], \"\[LongEqual]\"}], \
TraditionalForm], \"errors\" -> {}, \"input\" -> \
\"\\\\vec{A}\\\\cdot\\\\vec{B}=\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\"", ",", "14"}], "]"}], ",", 
                   RowBox[{"Round", "[", 
                    RowBox[{
                    RowBox[{"Dot", "[", 
                    RowBox[{"Avec", ",", "Bvec"}], "]"}], ",", "0.01"}], 
                    "]"}]}], "}"}]}], "}"}], "]"}]}], "]"}], ",", 
            RowBox[{"Style", "[", 
             RowBox[{"\"\<                  Cross Product\>\"", ",", "Bold"}],
              "]"}], ",", "\[IndentingNewLine]", "\[IndentingNewLine]", 
            RowBox[{"Labeled", "[", 
             RowBox[{
              RowBox[{"Graphics", "[", 
               RowBox[{
                RowBox[{"{", 
                 RowBox[{"Thick", ",", "Red", ",", "Agraphic", ",", 
                  RowBox[{"Darker", "@", "Red"}], ",", "Thick", ",", "Ax", 
                  ",", 
                  RowBox[{"Lighter", "@", "Red"}], ",", "Ay", ",", "Thick", 
                  ",", "Blue", ",", "Bgraphic", ",", 
                  RowBox[{"Darker", "@", "Blue"}], ",", "Thick", ",", "Bx", 
                  ",", 
                  RowBox[{"Lighter", "@", "Blue"}], ",", "By", ",", 
                  RowBox[{"Opacity", "[", "0.1", "]"}], ",", 
                  RowBox[{"Darker", "@", "Purple"}], ",", " ", 
                  RowBox[{"Rectangle", "[", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Avec", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                    RowBox[{"Bvec", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}], "]"}], ",", 
                  RowBox[{"Opacity", "[", "0.1", "]"}], ",", 
                  RowBox[{"Darker", "@", "Green"}], ",", " ", 
                  RowBox[{"Rectangle", "[", 
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"0", ",", "0"}], "}"}], ",", 
                    RowBox[{"{", 
                    RowBox[{
                    RowBox[{"Bvec", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", 
                    RowBox[{"Avec", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], "}"}]}], "]"}]}], "}"}],
                 ",", 
                RowBox[{"PlotRange", "\[Rule]", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
                   RowBox[{"{", 
                    RowBox[{
                    RowBox[{"-", "3"}], ",", "3"}], "}"}]}], "}"}]}], ",", 
                RowBox[{"ImageSize", "->", " ", "Medium"}], ",", 
                RowBox[{"Axes", "->", "True"}]}], "]"}], ",", 
              RowBox[{"Grid", "[", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Spacer", "[", "0.1", "]"}], ",", 
                   "\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
RowBox[{
SubscriptBox[
StyleBox[\"A\", \"TI\"], 
StyleBox[\"x\", \"TI\"]], \"\[LongEqual]\"}], TraditionalForm], \"errors\" -> \
{}, \"input\" -> \"A_x=\", \"state\" -> \"Boxes\"|>,\"TeXAssistantTemplate\"]\
\)\>\"", ",", 
                   RowBox[{"Round", "[", 
                    RowBox[{
                    RowBox[{"Avec", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", "0.01"}], "]"}], ",", 
                   RowBox[{"Spacer", "[", "0.5", "]"}], ",", 
                   "\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
RowBox[{
SubscriptBox[
StyleBox[\"A\", \"TI\"], 
StyleBox[\"y\", \"TI\"]], \"\[LongEqual]\"}], TraditionalForm], \"errors\" -> \
{}, \"input\" -> \"A_y=\", \"state\" -> \"Boxes\"|>,\"TeXAssistantTemplate\"]\
\)\>\"", ",", 
                   RowBox[{"Round", "[", 
                    RowBox[{
                    RowBox[{"Avec", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ",", "0.01"}], "]"}]}], 
                  "}"}], ",", "\[IndentingNewLine]", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Spacer", "[", "0.1", "]"}], ",", 
                   RowBox[{"Style", "[", 
                    RowBox[{"\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
RowBox[{
SubscriptBox[
StyleBox[\"B\", \"TI\"], 
StyleBox[\"x\", \"TI\"]], \"\[LongEqual]\"}], TraditionalForm], \"errors\" -> \
{}, \"input\" -> \"B_x=\", \"state\" -> \"Boxes\"|>,\"TeXAssistantTemplate\"]\
\)\>\"", ",", "14"}], "]"}], ",", 
                   RowBox[{"Round", "[", 
                    RowBox[{
                    RowBox[{"Bvec", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], ",", "0.01"}], "]"}], ",", 
                   RowBox[{"Spacer", "[", "0.2", "]"}], ",", 
                   RowBox[{"Style", "[", 
                    RowBox[{"\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
RowBox[{
SubscriptBox[
StyleBox[\"B\", \"TI\"], 
StyleBox[\"y\", \"TI\"]], \"\[LongEqual]\"}], TraditionalForm], \"errors\" -> \
{}, \"input\" -> \"B_y=\", \"state\" -> \"Boxes\"|>,\"TeXAssistantTemplate\"]\
\)\>\"", ",", "14"}], "]"}], ",", 
                   RowBox[{"Round", "[", 
                    RowBox[{
                    RowBox[{"Bvec", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], ",", "0.01"}], "]"}], ",", 
                   RowBox[{"Spacer", "[", "0.9", "]"}]}], "}"}], ",", 
                 "\[IndentingNewLine]", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Spacer", "[", "0.1", "]"}], ",", 
                   RowBox[{"Style", "[", 
                    RowBox[{"\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
RowBox[{
SubscriptBox[
StyleBox[\"A\", \"TI\"], 
StyleBox[\"x\", \"TI\"]], 
SubscriptBox[
StyleBox[\"B\", \"TI\"], 
StyleBox[\"y\", \"TI\"]], \"\[LongEqual]\"}], TraditionalForm], \"errors\" -> \
{}, \"input\" -> \"A_xB_y=\", \"state\" -> \"Boxes\"|>,\"TeXAssistantTemplate\
\"]\)\>\"", ",", "14"}], "]"}], ",", 
                   RowBox[{"Round", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Avec", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "*", 
                    RowBox[{"Bvec", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], ",", "0.01"}], "]"}], 
                   ",", 
                   RowBox[{"Spacer", "[", "0.5", "]"}], ",", 
                   RowBox[{"Style", "[", 
                    RowBox[{"\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
RowBox[{
SubscriptBox[
StyleBox[\"A\", \"TI\"], 
StyleBox[\"y\", \"TI\"]], 
SubscriptBox[
StyleBox[\"B\", \"TI\"], 
StyleBox[\"x\", \"TI\"]], \"\[LongEqual]\"}], TraditionalForm], \"errors\" -> \
{}, \"input\" -> \"A_yB_x=\", \"state\" -> \"Boxes\"|>,\"TeXAssistantTemplate\
\"]\)\>\"", ",", "14"}], "]"}], ",", 
                   RowBox[{"Round", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Avec", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "*", 
                    RowBox[{"Bvec", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}], ",", "0.01"}], "]"}]}], 
                  "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{
                   RowBox[{"Style", "[", 
                    RowBox[{"\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
RowBox[{
OverscriptBox[
StyleBox[\"A\", \"TI\"], \"\[RightVector]\"], \"\[Cross]\", 
OverscriptBox[
StyleBox[\"B\", \"TI\"], \"\[RightVector]\"], \"\[LongEqual]\", 
RowBox[{\"(\", 
RowBox[{
SubscriptBox[
StyleBox[\"A\", \"TI\"], 
StyleBox[\"x\", \"TI\"]], 
SubscriptBox[
StyleBox[\"B\", \"TI\"], 
StyleBox[\"y\", \"TI\"]], \"-\", 
SubscriptBox[
StyleBox[\"A\", \"TI\"], 
StyleBox[\"y\", \"TI\"]], 
SubscriptBox[
StyleBox[\"B\", \"TI\"], 
StyleBox[\"x\", \"TI\"]]}], \")\"}], 
OverscriptBox[
StyleBox[\"z\", \"TI\"], \"^\"]}], TraditionalForm], \"errors\" -> {}, \
\"input\" -> \"\\\\vec{A}\\\\times \
\\\\vec{B}=\\\\left(A_xB_y-A_yB_x\\\\right)\\\\hat{z}\", \"state\" -> \"Boxes\
\"|>,\"TeXAssistantTemplate\"]\)\>\"", ",", "14"}], "]"}], ",", 
                   RowBox[{"Spacer", "[", "0.1", "]"}], ",", 
                   RowBox[{"Style", "[", 
                    RowBox[{"\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
RowBox[{\"||\", 
OverscriptBox[
StyleBox[\"A\", \"TI\"], \"\[RightVector]\"], \"\[Cross]\", 
OverscriptBox[
StyleBox[\"B\", \"TI\"], \"\[RightVector]\"], \"||\", \"\[LongEqual]\"}], \
TraditionalForm], \"errors\" -> {}, \"input\" -> \
\"||\\\\vec{A}\\\\times\\\\vec{B}||=\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\"", ",", "14"}], "]"}], ",", 
                   RowBox[{"Round", "[", 
                    RowBox[{
                    RowBox[{"Sqrt", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"Avec", "[", 
                    RowBox[{"[", "1", "]"}], "]"}], "*", 
                    RowBox[{"Bvec", "[", 
                    RowBox[{"[", "2", "]"}], "]"}]}], "-", 
                    RowBox[{
                    RowBox[{"Avec", "[", 
                    RowBox[{"[", "2", "]"}], "]"}], "*", 
                    RowBox[{"Bvec", "[", 
                    RowBox[{"[", "1", "]"}], "]"}]}]}], ")"}], "^", "2"}], 
                    "]"}], ",", "0.01"}], "]"}]}], "}"}]}], "}"}], "]"}]}], 
             "]"}]}], "}"}], "]"}]}], "}"}], "]"}]}]}], "]"}], ",", 
   RowBox[{"Row", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Column", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Control", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "\[Theta]a", ",", "0", ",", 
              "\"\<Angle between A and the x axis\>\""}], "}"}], ",", "0", 
            ",", "360", ",", "5", ",", 
            RowBox[{"Appearance", "->", "\"\<Labeled\>\""}]}], "}"}], "]"}], 
         ",", "\[IndentingNewLine]", 
         RowBox[{"Control", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"La", ",", "2", ",", "\"\<Length of vector A\>\""}], 
             "}"}], ",", "0", ",", "3", ",", "0.1", ",", 
            RowBox[{"Appearance", "->", "\"\<Labeled\>\""}]}], "}"}], "]"}]}],
         "}"}], "]"}], ",", 
      RowBox[{"Column", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Control", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{
             "\[Theta]b", ",", "45", ",", 
              "\"\<Angle between B and the x axis\>\""}], "}"}], ",", "0", 
            ",", "360", ",", "5", ",", 
            RowBox[{"Appearance", "->", "\"\<Labeled\>\""}]}], "}"}], "]"}], 
         ",", ",", 
         RowBox[{"Control", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"Lb", ",", "2", ",", "\"\<Length of vector B\>\""}], 
             "}"}], ",", "0", ",", "3", ",", "0.1", ",", 
            RowBox[{"Appearance", "->", "\"\<Labeled\>\""}]}], "}"}], "]"}]}],
         "}"}], "]"}]}], "}"}], "]"}]}], "]"}]], "Input",
 CellOpen->False,
 CellChangeTimes->{{3.8851292772923374`*^9, 3.8851293973365154`*^9}, {
   3.8851294648993607`*^9, 3.8851298737737093`*^9}, {3.885129932105729*^9, 
   3.885129956556398*^9}, {3.88512999460291*^9, 3.885130134809119*^9}, {
   3.8851301908329744`*^9, 3.885130209873705*^9}, {3.885130287745248*^9, 
   3.885130333035371*^9}, {3.8851304361946535`*^9, 3.8851304862396727`*^9}, {
   3.885130543863366*^9, 3.8851305503955545`*^9}, {3.8851305810886374`*^9, 
   3.8851306158057275`*^9}, {3.885130705281393*^9, 3.8851307247542067`*^9}, {
   3.88513083093742*^9, 3.885130967429429*^9}, {3.8851311395861015`*^9, 
   3.885131147921499*^9}, {3.8851311802239723`*^9, 3.8851312390961037`*^9}, {
   3.8851314029455605`*^9, 3.8851314085800915`*^9}, {3.885131476882436*^9, 
   3.8851315431178236`*^9}, {3.8851316023728952`*^9, 3.885131749988244*^9}, 
   3.885131905895283*^9, {3.885131944205916*^9, 3.885131983544451*^9}, {
   3.885132043062398*^9, 3.885132043733507*^9}, {3.885132170702426*^9, 
   3.885132219473914*^9}, {3.8851322570568647`*^9, 3.8851323132005587`*^9}, {
   3.8851323961622562`*^9, 3.885132397576353*^9}, {3.885132429439808*^9, 
   3.8851325036319838`*^9}, {3.885132538349118*^9, 3.885132572539792*^9}, {
   3.8851326475997863`*^9, 3.8851326909620037`*^9}, {3.8851327323448825`*^9, 
   3.8851329713164635`*^9}, {3.8851330364044757`*^9, 
   3.8851330661524534`*^9}, {3.885133154663117*^9, 3.8851334304818397`*^9}, {
   3.885133463026702*^9, 3.8851334704862776`*^9}, {3.885133508516137*^9, 
   3.885133618769606*^9}, {3.885133715705896*^9, 3.8851337847112923`*^9}, {
   3.885133869565194*^9, 3.885133947251663*^9}, {3.885134016325422*^9, 
   3.8851341707033515`*^9}, {3.8851342794340816`*^9, 3.885134332266163*^9}, {
   3.8851343844787683`*^9, 3.8851345499781437`*^9}, {3.8851346633463907`*^9, 
   3.885134679063526*^9}, {3.8851353448308697`*^9, 3.8851353548885784`*^9}, {
   3.885135433512269*^9, 3.885135460744223*^9}, {3.8851356538658285`*^9, 
   3.8851357141177745`*^9}, {3.8851357632850685`*^9, 3.885135787125327*^9}, {
   3.8851358794121957`*^9, 3.885135880119705*^9}, {3.885135960691123*^9, 
   3.88513600294928*^9}, {3.8851360657659063`*^9, 3.8851361285661373`*^9}, {
   3.885136169469936*^9, 3.885136170398039*^9}, {3.885136262187133*^9, 
   3.885136269713482*^9}, {3.88513637814291*^9, 3.885136414815119*^9}, {
   3.8851365687958765`*^9, 3.885136599341464*^9}, {3.8851369090674915`*^9, 
   3.885136915390272*^9}, {3.885136971888477*^9, 3.8851369772673025`*^9}, {
   3.885138324401626*^9, 3.8851384251549015`*^9}, {3.8851384694653063`*^9, 
   3.8851384936281333`*^9}, {3.8851385382987747`*^9, 3.885138571355447*^9}, 
   3.885138602004386*^9, {3.8851386378326597`*^9, 3.8851386977724843`*^9}, {
   3.885138750817646*^9, 3.8851387529887824`*^9}, {3.8851387853005514`*^9, 
   3.8851387855631046`*^9}},
 CellLabel->
  "In[297]:=",ExpressionUUID->"300929e0-ed51-4a3f-8092-3604ca51efa3"],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`La$$ = 3., $CellContext`Lb$$ = 
    3., $CellContext`\[Theta]a$$ = 135, $CellContext`\[Theta]b$$ = 205, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`\[Theta]a$$], 0, "Angle between A and the x axis"}, 
      0, 360, 5}, {{
       Hold[$CellContext`La$$], 2, "Length of vector A"}, 0, 3, 0.1}, {{
       Hold[$CellContext`\[Theta]b$$], 45, "Angle between B and the x axis"}, 
      0, 360, 5}, {{
       Hold[$CellContext`Lb$$], 2, "Length of vector B"}, 0, 3, 0.1}, {
      Hold[
       Row[{
         Column[{
           Manipulate`Place[1], 
           Manipulate`Place[2]}], 
         Column[{
           Manipulate`Place[3], Null, 
           Manipulate`Place[4]}]}]], Manipulate`Dump`ThisIsNotAControl}}, 
    Typeset`size$$ = {801., {475.434033098002, 481.16596690199805`}}, 
    Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = True}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     2, StandardForm, 
      "Variables" :> {$CellContext`La$$ = 2, $CellContext`Lb$$ = 
        2, $CellContext`\[Theta]a$$ = 0, $CellContext`\[Theta]b$$ = 45}, 
      "ControllerVariables" :> {}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, "Body" :> 
      Module[{$CellContext`rad$, $CellContext`Ax$, $CellContext`Ay$, \
$CellContext`Bx$, $CellContext`By$, $CellContext`LabeledArrow$, \
$CellContext`LabeledArrow2$, $CellContext`Avec$, $CellContext`Bvec$, \
$CellContext`vecGraphic$, $CellContext`xComponent$, $CellContext`yComponent$, \
$CellContext`Agraphic$, $CellContext`Bgraphic$, $CellContext`ShiftedBy$, \
$CellContext`ShiftedyComponent$}, $CellContext`rad$[
           Pattern[$CellContext`\[Gamma], 
            Blank[]]] := $CellContext`\[Gamma] (Pi/
           180); $CellContext`LabeledArrow$[
           Pattern[$CellContext`p, 
            Blank[]], 
           Pattern[$CellContext`q, 
            Blank[]], 
           Pattern[$CellContext`label, 
            Blank[]]] := {
           Arrowheads[{{-0.035, 0}, {-0.014, 0.5, 
              Graphics[
               Inset[
                Style[$CellContext`label, Small], {Center, Top}]]}}], 
           
           Arrow[{$CellContext`q, $CellContext`p}]}; \
$CellContext`LabeledArrow2$[
           Pattern[$CellContext`p, 
            Blank[]], 
           Pattern[$CellContext`q, 
            Blank[]], 
           Pattern[$CellContext`label, 
            Blank[]]] := {
           Arrowheads[{{-0.035, 0}, {0.014, 0.5, 
              Graphics[
               Inset[
                Style[$CellContext`label, Small], {Center, Top}]]}}], 
           Arrow[{$CellContext`q, $CellContext`p}]}; $CellContext`vecGraphic$[
           Pattern[$CellContext`L$, 
            Blank[]], 
           Pattern[$CellContext`\[Theta]$, 
            Blank[]], 
           Pattern[Label$, 
            Blank[String]]] := 
         Module[{$CellContext`x$, $CellContext`y$}, $CellContext`x$ = \
$CellContext`L$ Cos[
               $CellContext`rad$[$CellContext`\[Theta]$]]; $CellContext`y$ = \
$CellContext`L$ Sin[
               $CellContext`rad$[$CellContext`\[Theta]$]]; Return[
             If[
              Or[$CellContext`\[Theta]$ < 90, $CellContext`\[Theta]$ > 270], 
              $CellContext`LabeledArrow$[{0, 
               0}, {$CellContext`x$, $CellContext`y$}, Label$], 
              $CellContext`LabeledArrow2$[{0, 
               0}, {$CellContext`x$, $CellContext`y$}, 
               Label$]]]]; $CellContext`ShiftedyComponent$[
           Pattern[$CellContext`L$, 
            Blank[]], 
           Pattern[$CellContext`\[Theta]$, 
            Blank[]], 
           Pattern[Label$, 
            Blank[String]]] := 
         Module[{$CellContext`x$, $CellContext`y$}, $CellContext`x$ = \
$CellContext`L$ Cos[
               $CellContext`rad$[$CellContext`\[Theta]$]]; $CellContext`y$ = \
$CellContext`L$ Sin[
               $CellContext`rad$[$CellContext`\[Theta]$]]; Return[
             If[
              Or[$CellContext`\[Theta]$ < 90, $CellContext`\[Theta]$ > 270], 
              $CellContext`LabeledArrow$[{$CellContext`x$, 
                0}, {$CellContext`x$, $CellContext`y$}, Label$], 
              $CellContext`LabeledArrow2$[{$CellContext`x$, 
                0}, {$CellContext`x$, $CellContext`y$}, 
               Label$]]]]; $CellContext`xComponent$[
           Pattern[$CellContext`L$, 
            Blank[]], 
           Pattern[$CellContext`\[Theta]$, 
            Blank[]], 
           Pattern[Label$, 
            Blank[String]]] := If[
           Or[$CellContext`\[Theta]$ < 90, $CellContext`\[Theta]$ > 270], 
           $CellContext`vecGraphic$[$CellContext`L$ Cos[
              $CellContext`rad$[$CellContext`\[Theta]$]], 0, Label$], 
           $CellContext`vecGraphic$[(-$CellContext`L$) Cos[
              $CellContext`rad$[$CellContext`\[Theta]$]], 180, 
            Label$]]; $CellContext`yComponent$[
           Pattern[$CellContext`L$, 
            Blank[]], 
           Pattern[$CellContext`\[Theta]$, 
            Blank[]], 
           Pattern[Label$, 
            Blank[String]]] := If[$CellContext`\[Theta]$ < 180, 
           $CellContext`vecGraphic$[$CellContext`L$ Sin[
              $CellContext`rad$[$CellContext`\[Theta]$]], 90, Label$], 
           $CellContext`vecGraphic$[(-$CellContext`L$) Sin[
              $CellContext`rad$[$CellContext`\[Theta]$]], 270, 
            Label$]]; $CellContext`Agraphic$ = \
$CellContext`vecGraphic$[$CellContext`La$$, $CellContext`\[Theta]a$$, 
           "A"]; $CellContext`Bgraphic$ = \
$CellContext`vecGraphic$[$CellContext`Lb$$, $CellContext`\[Theta]b$$, 
           "B"]; $CellContext`Ax$ = \
$CellContext`xComponent$[$CellContext`La$$, $CellContext`\[Theta]a$$, 
           "Ax"]; $CellContext`Ay$ = \
$CellContext`yComponent$[$CellContext`La$$, $CellContext`\[Theta]a$$, 
           "Ay"]; $CellContext`Bx$ = \
$CellContext`xComponent$[$CellContext`Lb$$, $CellContext`\[Theta]b$$, 
           "Bx"]; $CellContext`By$ = \
$CellContext`yComponent$[$CellContext`Lb$$, $CellContext`\[Theta]b$$, 
           "By"]; $CellContext`Avec$ = $CellContext`La$$ {
            Cos[
             $CellContext`rad$[$CellContext`\[Theta]a$$]], 
            Sin[
             $CellContext`rad$[$CellContext`\[Theta]a$$]]}; \
$CellContext`Bvec$ = $CellContext`Lb$$ {
            Cos[
             $CellContext`rad$[$CellContext`\[Theta]b$$]], 
            Sin[
             $CellContext`rad$[$CellContext`\[Theta]b$$]]}; \
$CellContext`ShiftedBy$ = $CellContext`ShiftedyComponent$[$CellContext`Lb$$, \
$CellContext`\[Theta]b$$, "By"]; Row[{
           Column[{
             Style["Vector A decomposition", Bold], 
             Graphics[{Thick, Red, $CellContext`Agraphic$, 
               Darker[Red], Thick, $CellContext`Ax$, 
               Lighter[Red], $CellContext`Ay$}, 
              PlotRange -> {{-3, 3}, {-3, 3}}, ImageSize -> Medium, Axes -> 
              True], 
             Style["Vector B decomposition", Bold], 
             Graphics[{Thick, Blue, $CellContext`Bgraphic$, 
               Darker[Blue], Thick, $CellContext`Bx$, 
               Lighter[Blue], $CellContext`By$, Thick, 
               Lighter[Blue], Dashed, $CellContext`ShiftedBy$}, 
              PlotRange -> {{-3, 3}, {-3, 3}}, ImageSize -> Medium, Axes -> 
              True]}], 
           Column[{
             Style["                  Dot Product", Bold], 
             Labeled[
              Graphics[{Thick, Red, $CellContext`Agraphic$, 
                Darker[Red], Thick, $CellContext`Ax$, 
                Lighter[Red], $CellContext`Ay$, Thick, 
                Blue, $CellContext`Bgraphic$, 
                Darker[Blue], Thick, $CellContext`Bx$, 
                Lighter[Blue], $CellContext`By$}, 
               PlotRange -> {{-3, 3}, {-3, 3}}, ImageSize -> Medium, Axes -> 
               True], 
              Grid[{{
                 Spacer[0.1], 
                 Style[
                 "\!\(\*TemplateBox[<|\"boxes\" -> \
FormBox[RowBox[{SubscriptBox[StyleBox[\"A\", \"TI\"], StyleBox[\"x\", \
\"TI\"]], \"\[LongEqual]\"}], TraditionalForm], \"errors\" -> {}, \"input\" \
-> \"A_x=\", \"state\" -> \"Boxes\"|>,\"TeXAssistantTemplate\"]\)", 14], 
                 Round[
                  Part[$CellContext`Avec$, 1], 0.01], 
                 Spacer[0.5], 
                 Style[
                 "\!\(\*TemplateBox[<|\"boxes\" -> \
FormBox[RowBox[{SubscriptBox[StyleBox[\"A\", \"TI\"], StyleBox[\"y\", \
\"TI\"]], \"\[LongEqual]\"}], TraditionalForm], \"errors\" -> {}, \"input\" \
-> \"A_y=\", \"state\" -> \"Boxes\"|>,\"TeXAssistantTemplate\"]\)", 14], 
                 Round[
                  Part[$CellContext`Avec$, 2], 0.01]}, {
                 Spacer[0.1], 
                 Style[
                 "\!\(\*TemplateBox[<|\"boxes\" -> \
FormBox[RowBox[{SubscriptBox[StyleBox[\"B\", \"TI\"], StyleBox[\"x\", \
\"TI\"]], \"\[LongEqual]\"}], TraditionalForm], \"errors\" -> {}, \"input\" \
-> \"B_x=\", \"state\" -> \"Boxes\"|>,\"TeXAssistantTemplate\"]\)", 14], 
                 Round[
                  Part[$CellContext`Bvec$, 1], 0.01], 
                 Spacer[0.2], 
                 Style[
                 "\!\(\*TemplateBox[<|\"boxes\" -> \
FormBox[RowBox[{SubscriptBox[StyleBox[\"B\", \"TI\"], StyleBox[\"y\", \
\"TI\"]], \"\[LongEqual]\"}], TraditionalForm], \"errors\" -> {}, \"input\" \
-> \"B_y=\", \"state\" -> \"Boxes\"|>,\"TeXAssistantTemplate\"]\)", 14], 
                 Round[
                  Part[$CellContext`Bvec$, 2], 0.01], 
                 Spacer[0.9]}, {
                 Spacer[0.1], 
                 Style[
                 "\!\(\*TemplateBox[<|\"boxes\" -> \
FormBox[RowBox[{SubscriptBox[StyleBox[\"A\", \"TI\"], StyleBox[\"x\", \
\"TI\"]], SubscriptBox[StyleBox[\"B\", \"TI\"], StyleBox[\"x\", \"TI\"]], \"\
\[LongEqual]\"}], TraditionalForm], \"errors\" -> {}, \"input\" -> \
\"A_xB_x=\", \"state\" -> \"Boxes\"|>,\"TeXAssistantTemplate\"]\)", 14], 
                 Round[
                 Part[$CellContext`Avec$, 1] Part[$CellContext`Bvec$, 1], 
                  0.01], 
                 Spacer[0.5], 
                 Style[
                 "\!\(\*TemplateBox[<|\"boxes\" -> \
FormBox[RowBox[{SubscriptBox[StyleBox[\"A\", \"TI\"], StyleBox[\"y\", \
\"TI\"]], SubscriptBox[StyleBox[\"B\", \"TI\"], StyleBox[\"y\", \"TI\"]], \"\
\[LongEqual]\"}], TraditionalForm], \"errors\" -> {}, \"input\" -> \
\"A_yB_y=\", \"state\" -> \"Boxes\"|>,\"TeXAssistantTemplate\"]\)", 14], 
                 Round[
                 Part[$CellContext`Avec$, 2] Part[$CellContext`Bvec$, 2], 
                  0.01]}, {
                 Style[
                 "\!\(\*TemplateBox[<|\"boxes\" -> \
FormBox[RowBox[{OverscriptBox[StyleBox[\"A\", \"TI\"], \"\[RightVector]\"], \
\"\[CenterDot]\", OverscriptBox[StyleBox[\"B\", \"TI\"], \"\[RightVector]\"], \
\"\[LongEqual]\", SubscriptBox[StyleBox[\"A\", \"TI\"], StyleBox[\"x\", \
\"TI\"]], SubscriptBox[StyleBox[\"B\", \"TI\"], StyleBox[\"x\", \"TI\"]], \"+\
\", SubscriptBox[StyleBox[\"A\", \"TI\"], StyleBox[\"y\", \"TI\"]], \
SubscriptBox[StyleBox[\"B\", \"TI\"], StyleBox[\"y\", \"TI\"]]}], \
TraditionalForm], \"errors\" -> {}, \"input\" -> \"\\\\vec{A}\\\\cdot \
\\\\vec{B}=A_xB_x+A_yB_y\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\)", 14], 
                 Spacer[0.1], 
                 Style[
                 "\!\(\*TemplateBox[<|\"boxes\" -> \
FormBox[RowBox[{OverscriptBox[StyleBox[\"A\", \"TI\"], \"\[RightVector]\"], \
\"\[CenterDot]\", OverscriptBox[StyleBox[\"B\", \"TI\"], \"\[RightVector]\"], \
\"\[LongEqual]\"}], TraditionalForm], \"errors\" -> {}, \"input\" -> \
\"\\\\vec{A}\\\\cdot\\\\vec{B}=\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\)", 14], 
                 Round[
                  Dot[$CellContext`Avec$, $CellContext`Bvec$], 0.01]}}]], 
             Style["                  Cross Product", Bold], 
             Labeled[
              Graphics[{Thick, Red, $CellContext`Agraphic$, 
                Darker[Red], Thick, $CellContext`Ax$, 
                Lighter[Red], $CellContext`Ay$, Thick, 
                Blue, $CellContext`Bgraphic$, 
                Darker[Blue], Thick, $CellContext`Bx$, 
                Lighter[Blue], $CellContext`By$, 
                Opacity[0.1], 
                Darker[Purple], 
                Rectangle[{0, 0}, {
                  Part[$CellContext`Avec$, 1], 
                  Part[$CellContext`Bvec$, 2]}], 
                Opacity[0.1], 
                Darker[Green], 
                Rectangle[{0, 0}, {
                  Part[$CellContext`Bvec$, 1], 
                  Part[$CellContext`Avec$, 2]}]}, 
               PlotRange -> {{-3, 3}, {-3, 3}}, ImageSize -> Medium, Axes -> 
               True], 
              Grid[{{
                 Spacer[0.1], 
                 "\!\(\*TemplateBox[<|\"boxes\" -> \
FormBox[RowBox[{SubscriptBox[StyleBox[\"A\", \"TI\"], StyleBox[\"x\", \
\"TI\"]], \"\[LongEqual]\"}], TraditionalForm], \"errors\" -> {}, \"input\" \
-> \"A_x=\", \"state\" -> \"Boxes\"|>,\"TeXAssistantTemplate\"]\)", 
                 Round[
                  Part[$CellContext`Avec$, 1], 0.01], 
                 Spacer[0.5], 
                 "\!\(\*TemplateBox[<|\"boxes\" -> \
FormBox[RowBox[{SubscriptBox[StyleBox[\"A\", \"TI\"], StyleBox[\"y\", \
\"TI\"]], \"\[LongEqual]\"}], TraditionalForm], \"errors\" -> {}, \"input\" \
-> \"A_y=\", \"state\" -> \"Boxes\"|>,\"TeXAssistantTemplate\"]\)", 
                 Round[
                  Part[$CellContext`Avec$, 2], 0.01]}, {
                 Spacer[0.1], 
                 Style[
                 "\!\(\*TemplateBox[<|\"boxes\" -> \
FormBox[RowBox[{SubscriptBox[StyleBox[\"B\", \"TI\"], StyleBox[\"x\", \
\"TI\"]], \"\[LongEqual]\"}], TraditionalForm], \"errors\" -> {}, \"input\" \
-> \"B_x=\", \"state\" -> \"Boxes\"|>,\"TeXAssistantTemplate\"]\)", 14], 
                 Round[
                  Part[$CellContext`Bvec$, 1], 0.01], 
                 Spacer[0.2], 
                 Style[
                 "\!\(\*TemplateBox[<|\"boxes\" -> \
FormBox[RowBox[{SubscriptBox[StyleBox[\"B\", \"TI\"], StyleBox[\"y\", \
\"TI\"]], \"\[LongEqual]\"}], TraditionalForm], \"errors\" -> {}, \"input\" \
-> \"B_y=\", \"state\" -> \"Boxes\"|>,\"TeXAssistantTemplate\"]\)", 14], 
                 Round[
                  Part[$CellContext`Bvec$, 2], 0.01], 
                 Spacer[0.9]}, {
                 Spacer[0.1], 
                 Style[
                 "\!\(\*TemplateBox[<|\"boxes\" -> \
FormBox[RowBox[{SubscriptBox[StyleBox[\"A\", \"TI\"], StyleBox[\"x\", \
\"TI\"]], SubscriptBox[StyleBox[\"B\", \"TI\"], StyleBox[\"y\", \"TI\"]], \"\
\[LongEqual]\"}], TraditionalForm], \"errors\" -> {}, \"input\" -> \
\"A_xB_y=\", \"state\" -> \"Boxes\"|>,\"TeXAssistantTemplate\"]\)", 14], 
                 Round[
                 Part[$CellContext`Avec$, 1] Part[$CellContext`Bvec$, 2], 
                  0.01], 
                 Spacer[0.5], 
                 Style[
                 "\!\(\*TemplateBox[<|\"boxes\" -> \
FormBox[RowBox[{SubscriptBox[StyleBox[\"A\", \"TI\"], StyleBox[\"y\", \
\"TI\"]], SubscriptBox[StyleBox[\"B\", \"TI\"], StyleBox[\"x\", \"TI\"]], \"\
\[LongEqual]\"}], TraditionalForm], \"errors\" -> {}, \"input\" -> \
\"A_yB_x=\", \"state\" -> \"Boxes\"|>,\"TeXAssistantTemplate\"]\)", 14], 
                 Round[
                 Part[$CellContext`Avec$, 2] Part[$CellContext`Bvec$, 1], 
                  0.01]}, {
                 Style[
                 "\!\(\*TemplateBox[<|\"boxes\" -> \
FormBox[RowBox[{OverscriptBox[StyleBox[\"A\", \"TI\"], \"\[RightVector]\"], \
\"\[Cross]\", OverscriptBox[StyleBox[\"B\", \"TI\"], \"\[RightVector]\"], \"\
\[LongEqual]\", RowBox[{\"(\", RowBox[{SubscriptBox[StyleBox[\"A\", \"TI\"], \
StyleBox[\"x\", \"TI\"]], SubscriptBox[StyleBox[\"B\", \"TI\"], \
StyleBox[\"y\", \"TI\"]], \"-\", SubscriptBox[StyleBox[\"A\", \"TI\"], \
StyleBox[\"y\", \"TI\"]], SubscriptBox[StyleBox[\"B\", \"TI\"], \
StyleBox[\"x\", \"TI\"]]}], \")\"}], OverscriptBox[StyleBox[\"z\", \"TI\"], \
\"^\"]}], TraditionalForm], \"errors\" -> {}, \"input\" -> \
\"\\\\vec{A}\\\\times \
\\\\vec{B}=\\\\left(A_xB_y-A_yB_x\\\\right)\\\\hat{z}\", \"state\" -> \"Boxes\
\"|>,\"TeXAssistantTemplate\"]\)", 14], 
                 Spacer[0.1], 
                 Style[
                 "\!\(\*TemplateBox[<|\"boxes\" -> FormBox[RowBox[{\"||\", \
OverscriptBox[StyleBox[\"A\", \"TI\"], \"\[RightVector]\"], \"\[Cross]\", \
OverscriptBox[StyleBox[\"B\", \"TI\"], \"\[RightVector]\"], \"||\", \"\
\[LongEqual]\"}], TraditionalForm], \"errors\" -> {}, \"input\" -> \
\"||\\\\vec{A}\\\\times\\\\vec{B}||=\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\)", 14], 
                 Round[
                  
                  Sqrt[(Part[$CellContext`Avec$, 1] 
                    Part[$CellContext`Bvec$, 2] - Part[$CellContext`Avec$, 2] 
                    Part[$CellContext`Bvec$, 1])^2], 0.01]}}]]}]}]], 
      "Specifications" :> {{{$CellContext`\[Theta]a$$, 0, 
          "Angle between A and the x axis"}, 0, 360, 5, Appearance -> 
         "Labeled", ControlPlacement -> 
         1}, {{$CellContext`La$$, 2, "Length of vector A"}, 0, 3, 0.1, 
         Appearance -> "Labeled", ControlPlacement -> 
         2}, {{$CellContext`\[Theta]b$$, 45, 
          "Angle between B and the x axis"}, 0, 360, 5, Appearance -> 
         "Labeled", ControlPlacement -> 
         3}, {{$CellContext`Lb$$, 2, "Length of vector B"}, 0, 3, 0.1, 
         Appearance -> "Labeled", ControlPlacement -> 4}, 
        Row[{
          Column[{
            Manipulate`Place[1], 
            Manipulate`Place[2]}], 
          Column[{
            Manipulate`Place[3], Null, 
            Manipulate`Place[4]}]}]}, "Options" :> {}, "DefaultOptions" :> {}],
     ImageSizeCache->{849., {537.134033098002, 542.865966901998}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.8851363878537445`*^9, 3.885136416397848*^9}, 
   3.885136602626192*^9, 3.8851369374106536`*^9, 3.885136983058487*^9, 
   3.8851387088166904`*^9, 3.8851387542077026`*^9, 3.885138788179562*^9},
 CellLabel->
  "Out[297]=",ExpressionUUID->"1d993aaf-17ab-4d6a-bccc-864fda00a068"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1283.25, 1005.75},
WindowMargins->{{Automatic, 507.75}, {Automatic, 4.5}},
FrontEndVersion->"13.2 for Microsoft Windows (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"3cbdef0c-050d-40ff-8017-e8d1c23bf338"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 235, 4, 98, "Title",ExpressionUUID->"fdd7ef63-d95a-4c69-ae57-0419edbe79a0"],
Cell[CellGroupData[{
Cell[840, 30, 237, 4, 69, "Chapter",ExpressionUUID->"d334e38b-2210-4f02-b519-3c1c5cb73a9d"],
Cell[1080, 36, 2669, 48, 227, "Text",ExpressionUUID->"3bd37227-8a2c-4316-85c3-4a71fbb857ff"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3786, 89, 161, 3, 69, "Chapter",ExpressionUUID->"ab9037fe-bc49-4696-817a-afc31aca4477"],
Cell[3950, 94, 830, 13, 74, "ItemNumbered",ExpressionUUID->"f853a84d-fb04-4e6a-b3ce-236bfbdc98c5"],
Cell[4783, 109, 3303, 72, 144, "ItemNumbered",ExpressionUUID->"a0966969-5997-4ba5-9633-a89c7125b4d8"],
Cell[CellGroupData[{
Cell[8111, 185, 904, 14, 53, "ItemNumbered",ExpressionUUID->"0483d961-251c-412a-8446-3a9312133846"],
Cell[9018, 201, 886, 14, 64, "SubitemNumbered",ExpressionUUID->"0d11ef12-38e9-4d7c-9421-85269dc3b49e"],
Cell[9907, 217, 1775, 35, 97, "SubitemNumbered",ExpressionUUID->"5d80dd09-ef20-4919-913c-42f051a4d4cf"],
Cell[11685, 254, 1670, 36, 55, "SubitemNumbered",ExpressionUUID->"54cd39bb-b24b-43e9-b27a-71854a520f79"],
Cell[13358, 292, 3157, 70, 71, "SubitemNumbered",ExpressionUUID->"e2021221-2778-46fe-853f-f790b25a0ddd"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16552, 367, 962, 14, 32, "ItemNumbered",ExpressionUUID->"10aa6de6-6f66-4ea6-83d6-0a7342762339"],
Cell[17517, 383, 1083, 16, 45, "SubitemNumbered",ExpressionUUID->"73c485a6-9397-416d-b354-d08a4004e188"],
Cell[18603, 401, 1173, 17, 45, "SubitemNumbered",ExpressionUUID->"1f3d6d71-53da-444d-871f-59226ae87314"],
Cell[19779, 420, 1313, 20, 45, "SubitemNumbered",ExpressionUUID->"ad4e93c8-064b-4b43-b060-63427bf7ca6f"],
Cell[21095, 442, 1387, 20, 45, "SubitemNumbered",ExpressionUUID->"3320587b-5936-43a0-be0d-ca78cb325379"],
Cell[22485, 464, 4015, 104, 52, "SubitemNumbered",ExpressionUUID->"68eb976f-3366-4ec5-8f96-37a6cf463628"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26537, 573, 2487, 42, 99, "ItemNumbered",ExpressionUUID->"305641db-844a-4453-9221-f89852783da7"],
Cell[CellGroupData[{
Cell[29049, 619, 1382, 31, 28, "SubitemNumbered",ExpressionUUID->"463acadd-c4a7-43bd-a97e-e690c76251ee"],
Cell[CellGroupData[{
Cell[30456, 654, 2033, 59, 19, "Input",ExpressionUUID->"484668f7-9a5a-4b04-8545-5f109ab7cb60",
 CellOpen->False],
Cell[32492, 715, 723, 13, 42, "Output",ExpressionUUID->"322887f6-c45e-489a-b4cb-0674b6b16387"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33252, 733, 32358, 747, 19, "Input",ExpressionUUID->"300929e0-ed51-4a3f-8092-3604ca51efa3",
 CellOpen->False],
Cell[65613, 1482, 18882, 379, 1099, "Output",ExpressionUUID->"1d993aaf-17ab-4d6a-bccc-864fda00a068"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

